@@ -3,6 +3,7 @@ DEFAULT_DETAIL_KEY = 'id'
 
 class RestApi:
     detail_key = DEFAULT_DETAIL_KEY
+    default_headers = {}
 
     def list(self, event, context):
         raise AttributeError('list method does not be implemented')
@@ -45,12 +46,18 @@ class RestApi:
         http_method = http_method.lower()
         return self.detail_methods.get(http_method, self.default) if is_detail else self.list_methods.get(http_method, self.default)
 
+    def decorate_response(self, response: dict):
+        if response.get('headers') == None:
+            response['headers'] = self.default_headers
+
     def create_handler(self):
 
         def handler(event, context):
             http_method = event['httpMethod']
             is_detail = event['pathParameters'].get(self.detail_key) != None
             rest_function = self.get_method(http_method, is_detail)
-            return rest_function(event, context)
+            response = rest_function(event, context)
+            self.decorate_response(response)
+            return response
 
         return handler
